onSetNull property
The function to call before value gets set to null.
When onSetNull gets called, value retains its previous value, which
may or may not be null.
This is useful when a column or columns represent a foreign key, and you need to delete the other side of a one-to-one relationship.
Implementation
final Future<void> Function(GeneratedDatabase database)? onSetNull;